'************************************************
' File:   ShellFileOperation.vbs (WSH-sample in VBScript) 
' Author: G. Born
'
' Demonstrate how to access Shell API function 
' SHFileOperation to handle file operations
' using an ActiveX control.
'************************************************
Option Explicit

' Constant definitions for SHFileOperation
Const FO_MOVE = &H1
Const FO_COPY = &H2
Const FO_DELETE = &H3
Const FO_RENAME = &H4
Const FOF_MULTIDESTFILES = &H1
Const FOF_CONFIRMMOUSE = &H2
Const FOF_SILENT = &H4              '  don't create progress/report
Const FOF_RENAMEONCOLLISION = &H8
Const FOF_NOCONFIRMATION = &H10     '  No user prompt 

Const FOF_ALLOWUNDO = &H40
Const FOF_FILESONLY = &H80          '  on *.* (do only files - not directories)
Const FOF_SIMPLEPROGRESS = &H100    '  don't show names of files
Const FOF_NOCONFIRMMKDIR = &H200    '  don't confirm making any needed dirs


Dim oShExt, code
Dim source, destin

' create object reference
Set oShExt = WScript.CreateObject("ShellExtension.ShellObjects")

' Get source and destination file
 source = GetPath() & "T.txt"     ' a test file in current folder
 destin = GetPath() & "CopyTest.txt" 

'### Try Copy operation
If MsgBox ("Copy: " & source & vbCRLF & "to: " & destin, _
           vbYesNo + vbQuestion, "SHFileOperation")  = vbYes Then
' copy the text file
 code = oShExt.WSHFileOperation ( _
      FO_COPY, source, destin, _
      FOF_FILESONLY + FOF_ALLOWUNDO + FOF_SIMPLEPROGRESS)
 If code <> 0 Then
  MsgBox "Error, Code is " & code
 Else
  MsgBox "File " & source & " copied to " & destin, _
         vbInformation, "File Operation"
 End if
End if

'### Try Move operation
' Get source and destination file
 source = GetPath() & "CopyTest.txt"  ' a test file in current folder
 destin = GetPath() & "MyTest.txt" 
If MsgBox ("Move: " & source & vbCRLF & "to: " & destin, _
           vbYesNo + vbQuestion, "SHFileOperation") = vbYes Then
' move the text file
 code = oShExt.WSHFileOperation ( _
      FO_MOVE, source, destin, _
      FOF_FILESONLY)
 If code <> 0 Then
  MsgBox "Error, Code is " & code
 Else
  MsgBox "File " & source & " moved to " & destin, _
         vbInformation, "File Operation"
 End if
End if

'### Try Rename operation
' Get source and destination file
 source = GetPath() & "MyTest.txt"  ' a test file in current folder
 destin = GetPath() & "CopyTest.txt" 
If MsgBox ("Rename: "& source & vbCRLF & "to: " & destin, _
           vbYesNo + vbQuestion, "SHFileOperation") = vbYes Then
' Rename file
 code = oShExt.WSHFileOperation ( _
      FO_MOVE, source, destin, _
      FOF_FILESONLY)
 If code <> 0 Then
  MsgBox "Error, Code is " & code
 Else
  MsgBox "File " & source & " renamed to " & destin, _
         vbInformation, "File Operation"
 End if
End if

'### Try Delete operation
' Get source, set destination file to blank
 source = GetPath() & "CopyTest.txt"  ' a test file in current folder
 destin = GetPath() & "" 
If MsgBox ("Delete: " & source, _
           vbYesNo + vbQuestion, "SHFileOperation") = vbYes Then
' delete file
 code = oShExt.WSHFileOperation ( _
      FO_DELETE, source, destin, _
      FOF_FILESONLY + FOF_ALLOWUNDO)
 If code <> 0 Then
  MsgBox "Error, Code is " & code
 Else
  MsgBox "File " & source & " deleted", _
         vbInformation, "File Operation"
 End if
End if

'##########################
Function GetPath
' Retrieve the script path
 DIM path
 path = WScript.ScriptFullName  ' Script name
 GetPath = Left(path, InstrRev(path, "\"))
End Function
'*** End